@@ -13,7 +13,7 @@ class KuakeIface : virtual public DCOPObject
 public:
 
 k_dcop:
-  virtual void setKuakeState(int i) = 0;
+  virtual void setKuakeState() = 0;
 };
 
 #endif // _KUAKEIFACE_H_
